@@ -5,6 +5,9 @@ from .liquidpy import liquidpy_parser
 from .numpy import numpy_parser
 from .parsed import pretty
 
+__version__ = "0.1.0"
+
+
 def auto_parser(docstring):
     """Try to get a proper parser for the given docstring
 
@@ -26,4 +29,4 @@ def auto_parser(docstring):
             last_exc = ex
             continue
 
-    raise ValueError('All parsers failed') from last_exc
+    raise ValueError("All parsers failed") from last_exc
